==> graphql-dgs-8.5.3-sources.jar: main/com/netflix/graphql/dgs/internal/VirtualThreadTaskExecutor.java <==
/*
 * Copyright 2023 Netflix, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.netflix.graphql.dgs.internal;

import org.jetbrains.annotations.NotNull;
import org.springframework.core.task.AsyncTaskExecutor;

import java.util.concurrent.Callable;
import java.util.concurrent.Future;

/**
 * Unimplemented version of the VirtualThreadTaskExecutor just for reachability.
 * The actual implementation is in the java21 source folder, using the multi-release JAR feature.
 */
public class VirtualThreadTaskExecutor implements AsyncTaskExecutor {
    public VirtualThreadTaskExecutor() {
    }

    @Override
    public void execute(@NotNull Runnable task) {
        throw new UnsupportedOperationException("VirtualThreadTaskExecutor is only supported on JDK 21+");
    }

    @Override
    @Deprecated
    public void execute(@NotNull Runnable task, long startTimeout) {
        throw new UnsupportedOperationException("VirtualThreadTaskExecutor is only supported on JDK 21+");
    }

    @NotNull
    @Override
    public Future<?> submit(@NotNull Runnable task) {
        throw new UnsupportedOperationException("VirtualThreadTaskExecutor is only supported on JDK 21+");
    }

    @NotNull
    @Override
    public <T> Future<T> submit(@NotNull Callable<T> task) {
        throw new UnsupportedOperationException("VirtualThreadTaskExecutor is only supported on JDK 21+");
    }
}

==> graphql-dgs-8.5.7-sources.jar: main/com/netflix/graphql/dgs/internal/VirtualThreadTaskExecutor.java <==
/*
 * Copyright 2023 Netflix, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.netflix.graphql.dgs.internal;

import io.micrometer.context.ContextSnapshotFactory;
import org.jetbrains.annotations.NotNull;
import org.springframework.core.task.AsyncTaskExecutor;

import java.util.concurrent.Callable;
import java.util.concurrent.Future;

/**
 * Unimplemented version of the VirtualThreadTaskExecutor just for reachability.
 * The actual implementation is in the java21 source folder, using the multi-release JAR feature.
 */
public class VirtualThreadTaskExecutor implements AsyncTaskExecutor {
    public VirtualThreadTaskExecutor(ContextSnapshotFactory contextSnapshotFactory) {
    }

    @Override
    public void execute(@NotNull Runnable task) {
        throw new UnsupportedOperationException("VirtualThreadTaskExecutor is only supported on JDK 21+");
    }

    @Override
    @Deprecated
    public void execute(@NotNull Runnable task, long startTimeout) {
        throw new UnsupportedOperationException("VirtualThreadTaskExecutor is only supported on JDK 21+");
    }

    @NotNull
    @Override
    public Future<?> submit(@NotNull Runnable task) {
        throw new UnsupportedOperationException("VirtualThreadTaskExecutor is only supported on JDK 21+");
    }

    @NotNull
    @Override
    public <T> Future<T> submit(@NotNull Callable<T> task) {
        throw new UnsupportedOperationException("VirtualThreadTaskExecutor is only supported on JDK 21+");
    }
}
